@@ -1,6 +1,7 @@
 """
-This module provides the base class that is used to wrap the various DAG task methods. It
-provides support for user-defined setup and cleanup, task monitoring using Elastic APM,
+Base class that is used to wrap the various DAG task methods.
+
+It provides support for user-defined setup and cleanup, task monitoring using Elastic APM,
 standardized logging and exception handling.
 """
 import json
@@ -23,7 +24,8 @@ logger = logging.getLogger(__name__)
 class ApmTransaction:
     """
     Elastic APM transaction manager for a DAG Task.
-        Without configuration it self disables
+
+    Without configuration it disables itself.
     """
 
     @property
@@ -107,10 +109,7 @@ class ApmTransaction:
 
     @staticmethod
     def instrument():
-        """
-        Vendored implementation of elasticapm.instrumentation.control.instrument changed to
-          omit certain frameworks
-        """
+        """Vendored implementation of elasticapm.instrumentation.control.instrument changed to omit certain frameworks."""
         omit_frameworks = {
             "elasticapm.instrumentation.packages.redis.RedisInstrumentation",
             "elasticapm.instrumentation.packages.redis.RedisPipelineInstrumentation",
@@ -149,6 +148,7 @@ class ApmTransaction:
 class TaskBase(ABC):
     """
     Generic wrapper for the DAG tasks providing a standard interface and execution flow.
+
     Each DAG task must implement its own subclass of this abstract wrapper class.
 
     Intended instantiation is as a context manager
@@ -183,6 +183,7 @@ class TaskBase(ABC):
         name of the workflow to which this instance of the task belongs
     workflow_version : str
         version of the workflow to which this instance of the task belongs
+
     """
 
     retries = 0
@@ -194,6 +195,7 @@ class TaskBase(ABC):
         workflow_name: str,
         workflow_version: str,
     ):
+        """Task base construction."""
         self.recipe_run_id = int(recipe_run_id)
         self.workflow_name = workflow_name
         self.workflow_version = workflow_version
@@ -207,27 +209,20 @@ class TaskBase(ABC):
         self.apm_step = self.apm.capture_span  # abbreviated syntax for capture span context mgr
 
     def pre_run(self) -> None:
-        """
-        Method intended to be overridden that will execute prior to run() with Elastic APM span
-        capturing
-        """
+        """Intended to be overridden and will execute prior to run() with Elastic APM span capturing."""
 
     @abstractmethod
     def run(self) -> None:
-        """
-        Abstract method that must be overridden to execute the desired DAG task.
-        """
+        """Abstract method that must be overridden to execute the desired DAG task."""
 
     def post_run(self) -> None:
-        """
-        Method intended to be overridden that will execute after run() with Elastic APM span
-        capturing
-        """
+        """Intended to be overridden and will execute after run() with Elastic APM span capturing."""
 
     def __call__(self) -> None:
         """
-        The main executable function for the DAG task wrapper. Execution is instrumented with
-        Application Performance Monitoring if configured. The standard execution sequence is:
+        DAG task wrapper. Execution is instrumented with Application Performance Monitoring if configured.
+
+        The standard execution sequence is:
 
         1 run
 
@@ -236,8 +231,8 @@ class TaskBase(ABC):
         Returns
         -------
         None
-        """
 
+        """
         logger.info(f"Task {self.task_name} started")
         with self.apm_step("Pre Run", span_type="code.core", labels={"type": "core"}):
             self.pre_run()
@@ -248,18 +243,27 @@ class TaskBase(ABC):
         logger.info(f"Task {self.task_name} complete")
 
     def __enter__(self):
+        """
+        Override to execute setup tasks before task execution.
+
+        Only override this method with tasks that need to happen
+        regardless of tasks having an exception, ensure that no additional exception
+        will be raised, and always call super().__enter__
+        """
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         """
-        Method that can be overridden to execute teardown tasks after task execution regardless
-        of task execution success.  Only override this method with tasks that need to happen
+        Override to execute teardown tasks after task execution regardless of task execution success.
+
+        Only override this method with tasks that need to happen
         regardless of tasks having an exception, ensure that no additional exception
         will be raised, and always call super().__exit__
         """
         self.apm.close(exc_type=exc_type)
 
     def __repr__(self):
+        """Return the representation of the task."""
         return (
             f"{self.__class__.__name__}("
             f"recipe_run_id={self.recipe_run_id}, "
@@ -269,4 +273,5 @@ class TaskBase(ABC):
         )
 
     def __str__(self):
+        """Return a string representation of the task."""
         return repr(self)
