@@ -9,7 +9,10 @@ from dkist_processing_core.tests.task_example import Task2
 
 
 example = Workflow(
-    process_category="invalid", process_name="workflow", workflow_package=__package__
+    input_data="test-data",
+    output_data="invalid",
+    category="core",
+    workflow_package=__package__,
 )
 example.add_node(task=Task, upstreams=Task2)
 example.add_node(task=Task2, upstreams=Task)
