@@ -1,6 +1,6 @@
 """Abstraction layer to construct a workflow as an airflow DAG."""
 import json
-import logging
+import string
 from os import environ
 from pathlib import Path
 from typing import List
@@ -15,6 +15,8 @@ from dkist_processing_core._node import upstreams_type_hint
 
 __all__ = ["Workflow"]
 
+MAXIMUM_ALLOWED_WORKFLOW_NAME_LENGTH = 50
+
 
 class Workflow:
     """
@@ -27,20 +29,32 @@ class Workflow:
     - contains nodes and the relationships between them
 
     >>> category = "instrument"
-    >>> name = "calibration_name"
+    >>> input_data = "l0"
+    >>> output_data = "l1"
+    >>> detail = "OCP-use-only"
     >>> version = "V6-12342"
+    >>> tags = ["use-XYZ-algorithm"]
     >>> task = Task()
     >>> workflow_instance = Workflow(
-    >>>    process_category=category, process_name=name, workflow_package=__package__, workflow_version=version,
+    >>>    category=category,
+    >>>    input_data=input_data,
+    >>>    output_data=output_data,
+    >>>    detail=detail,
+    >>>    workflow_package=__package__,
+    >>>    workflow_version=version,
+    >>>    tags=tags
     >>>)
     >>> workflow_instance.add_node(task=task, upstreams=None)
     """
 
     def __init__(
         self,
-        process_category: str,
-        process_name: str,
+        *,
+        input_data: str,
+        output_data: str,
+        category: str,
         workflow_package: str,
+        detail: Optional[str] = None,
         tags: Optional[List[str]] = None,
         workflow_version: Optional[str] = None,
     ):
@@ -49,8 +63,10 @@ class Workflow:
 
         Parameters
         ----------
-        process_category: Category for the process the workflow executes e.g. instrument name
-        process_name: Name for the process the workflow executes e.g. algorithm name
+        input_data: Description of the primary inputs to the workflow e.g. l0
+        output_data: Description of the primary outputs of the workflow e.g. l1
+        category: Category for the process the workflow executes e.g. instrument name
+        detail: Extra information to separate this workflow from a similar workflow
         workflow_package: The string representing the dot notation location of the
           workflow definition. e.g. __package__
         tags: tags to be used in airflow's UI when searching for dags
@@ -59,25 +75,78 @@ class Workflow:
 
         """
         self.workflow_package = workflow_package
-        self.process_category = process_category
-        self.process_name = process_name
-        self.workflow_name = f"{self.process_category}_{self.process_name}"
+        self.category = category
+        self.input_data = input_data
+        self.output_data = output_data
+        self.detail = detail
+        self.workflow_name = self.get_workflow_name(
+            input_data=self.input_data,
+            output_data=self.output_data,
+            category=self.category,
+            detail=self.detail,
+        )
         self.workflow_version = workflow_version or environ.get("BUILD_VERSION", "dev")
         self.tags = tags or []
         self._dag_name = f"{self.workflow_name}_{self.workflow_version}"
+        self.check_dag_name_characters(self._dag_name)
         self._dag = self._initialize_local_dag()
         self.nodes = []
 
+    @staticmethod
+    def get_workflow_name(
+        *,
+        input_data: str,
+        output_data: str,
+        category: str,
+        detail: str = None,
+        **kwargs,
+    ) -> str:
+        """Create the workflow name from its constituent parts."""
+        workflow_name = f"{input_data}_to_{output_data}_{category}"
+        if detail:
+            workflow_name += f"_{detail}"
+        if len(workflow_name) > MAXIMUM_ALLOWED_WORKFLOW_NAME_LENGTH:
+            raise ValueError(
+                f"Workflow name {workflow_name} is {len(workflow_name)} characters long. "
+                f"Limit is {MAXIMUM_ALLOWED_WORKFLOW_NAME_LENGTH} characters."
+            )
+        return workflow_name
+
+    @staticmethod
+    def check_dag_name_characters(dag_name: str):
+        """
+        Figure out if the dag name is an Airflow-allowed name.
+
+        Can only contain
+        * ascii letters
+        * numbers
+        * dash (-)
+        * dot (.)
+        * underscore (_)
+
+        Raise error if non-allowed characters are found.
+        """
+        allowed_chars = (
+            [c for c in string.ascii_letters] + ["-", ".", "_"] + [n for n in string.digits]
+        )
+        if not all([char in allowed_chars for char in dag_name]):
+            raise ValueError(
+                f"Dag name {dag_name} contains invalid characters. "
+                f"Only ascii letters and the dash, dot, and "
+                f"underscore symbols are permitted."
+            )
+
     @property
     def _dag_tags(self) -> str:
         """
         Return the list of dag tags to be used in Airflow's UI.
 
-        Equal to the list of supplied tags plus the workflow version.
+        Equal to the list of supplied tags plus the workflow version, input and output data,
+        and category.
         """
         if isinstance(self.tags, str):
             self.tags = [self.tags]
-        tags = self.tags + [self.workflow_version]
+        tags = self.tags + [self.workflow_version, self.input_data, self.output_data, self.category]
         # Make sure there are no duplicate tags
         tags = list(set(tags))
         return json.dumps(tags)
@@ -170,8 +239,10 @@ class Workflow:
         """Detailed representation of the workflow."""
         return (
             f"Workflow("
-            f"process_category={self.process_category}, "
-            f"process_name={self.process_name}, "
+            f"input_data={self.input_data}, "
+            f"output_data={self.output_data}, "
+            f"category={self.category}, "
+            f"detail={self.detail}, "
             f"workflow_package={self.workflow_package}, "
             f"workflow_version={self.workflow_version}, "
             f")"
